@@ -11,12 +11,13 @@ from .utils import _split_arg
 __all__ = ["JsocInfoConstants", "HttpJsonRequest", "HttpJsonClient"]
 
 
-class JsocInfoConstants(Enum):
+# TODO: When we support 3.11, we can use StrEnum instead of Enum
+class JsocInfoConstants(str, Enum):
     """
     Constants for DRMS queries.
     """
 
-    all = "**ALL**"  # NOQA: A003
+    all = "**ALL**"
     none = "**NONE**"
     recdir = "*recdir*"
     dirmtime = "*dirmtime*"
